==> sharyn-11.0.0.tgz: package/redux/ui-reductions.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _compose = _interopRequireDefault(require("recompose/compose"));

var _uiReductions = require("./ui-reductions");

test('addOneNotificationReduction', function () {
  return expect((0, _uiReductions.addOneNotificationReduction)('notif')({
    notifications: []
  })).toEqual({
    notifications: ['notif']
  });
});
test('addMultipleNotificationsReduction', function () {
  return expect((0, _uiReductions.addMultipleNotificationsReduction)(['a', 'b'])({
    notifications: []
  })).toEqual({
    notifications: ['a', 'b']
  });
});
test('removeFirstNotificationReduction', function () {
  return expect((0, _uiReductions.removeFirstNotificationReduction)()({
    notifications: ['a', 'b']
  })).toEqual({
    notifications: ['b']
  });
});
test('setUiReduction', function () {
  var uiState = {
    foo: 'foo'
  };
  expect((0, _uiReductions.setUiReduction)({
    bar: 'baz'
  })(uiState)).toEqual({
    foo: 'foo',
    bar: 'baz'
  });
  expect((0, _compose.default)((0, _uiReductions.setUiReduction)({
    bar: 'baz'
  }))(uiState)).toEqual({
    foo: 'foo',
    bar: 'baz'
  });
});
test('deleteUiReduction', function () {
  var uiState = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _uiReductions.deleteUiReduction)('bar')(uiState)).toEqual({
    foo: 'foo'
  });
  expect((0, _compose.default)((0, _uiReductions.deleteUiReduction)('bar'))(uiState)).toEqual({
    foo: 'foo'
  });
});

==> sharyn-11.4.0.tgz: package/redux/ui-reductions.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _compose = _interopRequireDefault(require("recompose/compose"));

var _uiReductions = require("./ui-reductions");

test('addOneNotificationReduction', function () {
  return expect((0, _uiReductions.addOneNotificationReduction)('notif')({
    notifications: []
  })).toEqual({
    notifications: ['notif']
  });
});
test('addMultipleNotificationsReduction', function () {
  return expect((0, _uiReductions.addMultipleNotificationsReduction)(['a', 'b'])({
    notifications: []
  })).toEqual({
    notifications: ['a', 'b']
  });
});
test('removeFirstNotificationReduction', function () {
  return expect((0, _uiReductions.removeFirstNotificationReduction)()({
    notifications: ['a', 'b']
  })).toEqual({
    notifications: ['b']
  });
});
test('setUiReduction', function () {
  var uiState = {
    foo: 'foo'
  };
  expect((0, _uiReductions.setUiReduction)({
    bar: 'baz'
  })(uiState)).toEqual({
    foo: 'foo',
    bar: 'baz'
  });
  expect((0, _compose["default"])((0, _uiReductions.setUiReduction)({
    bar: 'baz'
  }))(uiState)).toEqual({
    foo: 'foo',
    bar: 'baz'
  });
});
test('deleteUiReduction', function () {
  var uiState = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _uiReductions.deleteUiReduction)('bar')(uiState)).toEqual({
    foo: 'foo'
  });
  expect((0, _compose["default"])((0, _uiReductions.deleteUiReduction)('bar'))(uiState)).toEqual({
    foo: 'foo'
  });
});
